pub struct KeyInfo {
pub key_name: String,
pub public_key: String,
pub requires_authentication: Option<bool>,
}Expand description
Information about a key
Fields
key_name: StringThe key name/identifier
public_key: StringThe public key in base64 encoding
requires_authentication: Option<bool>Whether this key requires authentication to use None if it cannot be determined whether authentication is required